@@ -4,15 +4,15 @@ use actix_multipart::Multipart;
 use actix_web::{web, HttpResponse};
 use async_std::prelude::*;
 use atomic_lib::{
-    commit::CommitResponse, datetime_helpers::now, hierarchy::check_write, urls, AtomicError,
-    Resource, Storelike, Value,
+    commit::CommitResponse, hierarchy::check_write, urls, utils::now, AtomicError, Resource,
+    Storelike, Value,
 };
 use futures::{StreamExt, TryStreamExt};
 use serde::Deserialize;
 
 use crate::{appstate::AppState, errors::AtomicServerResult, helpers::get_client_agent};
 
-#[derive(Deserialize)]
+#[derive(Deserialize, Debug)]
 pub struct UploadQuery {
     parent: String,
 }
@@ -23,6 +23,7 @@ pub struct UploadQuery {
 /// Submission is done using multipart/form-data.
 /// The file is stored in the `/uploads` directory.
 /// An `attachment` relationship is created from the parent
+#[tracing::instrument(skip(data, req, body))]
 pub async fn upload_handler(
     mut body: Multipart,
     data: web::Data<Mutex<AppState>>,
@@ -71,7 +72,7 @@ pub async fn upload_handler(
 
         // Field in turn is stream of *Bytes* object
         while let Some(chunk) = field.next().await {
-            let data = chunk.unwrap();
+            let data = chunk.map_err(|e| format!("Error while reading multipart data. {}", e))?;
             // TODO: Update a SHA256 hash here for checksum
             file.write_all(&data).await?;
         }
