@@ -6,35 +6,17 @@ use crate::appstate::AppState;
 
 use super::*;
 use actix_web::{
-    dev::{Body, ResponseBody},
+    body::MessageBody,
+    dev::ServiceResponse,
     test::{self, TestRequest},
     web::Data,
     App,
 };
 use atomic_lib::{urls, Storelike};
 
-trait BodyTest {
-    fn as_str(&self) -> &str;
-}
-
-impl BodyTest for ResponseBody<Body> {
-    fn as_str(&self) -> &str {
-        match self {
-            ResponseBody::Body(ref b) => match b {
-                Body::Bytes(ref by) => std::str::from_utf8(by).unwrap(),
-                _ => panic!(),
-            },
-            ResponseBody::Other(ref b) => match b {
-                Body::Bytes(ref by) => std::str::from_utf8(by).unwrap(),
-                _ => panic!(),
-            },
-        }
-    }
-}
-
 /// Returns the request with signed headers. Also adds a json-ad accept header - overwrite this if you need something else.
 fn build_request_authenticated(path: &str, appstate: &AppState) -> TestRequest {
-    let url = format!("{}{}", appstate.store.get_base_url(), path);
+    let url = format!("{}{}", appstate.store.get_server_url(), path);
     let headers = atomic_lib::client::get_authentication_headers(
         &url,
         &appstate.store.get_default_agent().unwrap(),
@@ -43,9 +25,9 @@ fn build_request_authenticated(path: &str, appstate: &AppState) -> TestRequest {
 
     let mut prereq = test::TestRequest::with_uri(path);
     for (k, v) in headers {
-        prereq = prereq.header(k, v.clone());
+        prereq = prereq.insert_header((k, v));
     }
-    prereq.header("Accept", "application/ad+json")
+    prereq.insert_header(("Accept", "application/ad+json"))
 }
 
 #[actix_rt::test]
@@ -58,7 +40,7 @@ async fn server_tests() {
         .expect("failed init config");
     let appstate = crate::appstate::init(config.clone()).expect("failed init appstate");
     let data = Data::new(std::sync::Mutex::new(appstate.clone()));
-    let mut app = test::init_service(
+    let app = test::init_service(
         App::new()
             .app_data(data)
             .configure(|app| crate::routes::config_routes(app, &appstate.config)),
@@ -68,30 +50,32 @@ async fn server_tests() {
 
     // Does not work, unfortunately, because the server is not accessible.
     // let fetched =
-    //     atomic_lib::client::fetch_resource(&appstate.config.local_base_url, &appstate.store, None)
+    //     atomic_lib::client::fetch_resource(&appstate.config.server_url, &appstate.store, None)
     //         .expect("could not fetch drive");
 
     // Get HTML page
-    let req = build_request_authenticated("/", &appstate).header("Accept", "application/html");
-    let mut resp = test::call_service(&mut app, req.to_request()).await;
+    let req =
+        build_request_authenticated("/", &appstate).insert_header(("Accept", "application/html"));
+    let resp = test::call_service(&app, req.to_request()).await;
     assert!(resp.status().is_success());
-    let body = resp.take_body();
-    assert!(body.as_str().contains("html"), "no html in response");
+    let body = get_body(resp);
+    assert!(body.as_str().contains("html"));
 
     // Should 200 (public)
-    let req = test::TestRequest::with_uri("/properties").header("Accept", "application/ad+json");
-    let resp = test::call_service(&mut app, req.to_request()).await;
+    let req =
+        test::TestRequest::with_uri("/properties").insert_header(("Accept", "application/ad+json"));
+    let resp = test::call_service(&app, req.to_request()).await;
     assert_eq!(resp.status().as_u16(), 200, "resource should be public");
 
     // Should 404
     let req = test::TestRequest::with_uri("/doesnotexist")
-        .header("Accept", "application/ld+json")
+        .append_header(("Accept", "application/ld+json"))
         .to_request();
-    let resp = test::call_service(&mut app, req).await;
+    let resp = test::call_service(&app, req).await;
     assert!(resp.status().is_client_error());
 
     // Edit the properties collection, make it hidden to the public agent
-    let mut drive = store.get_resource(&appstate.config.local_base_url).unwrap();
+    let mut drive = store.get_resource(&appstate.config.server_url).unwrap();
     drive
         .set_propval(
             urls::READ.into(),
@@ -102,8 +86,9 @@ async fn server_tests() {
     drive.save(store).unwrap();
 
     // Should 401 (Unauthorized)
-    let req = test::TestRequest::with_uri("/properties").header("Accept", "application/ad+json");
-    let resp = test::call_service(&mut app, req.to_request()).await;
+    let req =
+        test::TestRequest::with_uri("/properties").insert_header(("Accept", "application/ad+json"));
+    let resp = test::call_service(&app, req.to_request()).await;
     assert_eq!(
         resp.status().as_u16(),
         401,
@@ -112,9 +97,9 @@ async fn server_tests() {
 
     // Get JSON-AD
     let req = build_request_authenticated("/properties", &appstate);
-    let mut resp = test::call_service(&mut app, req.to_request()).await;
+    let resp = test::call_service(&app, req.to_request()).await;
     assert!(resp.status().is_success(), "setup not returning JSON-AD");
-    let body = resp.take_body();
+    let body = get_body(resp);
     assert!(
         body.as_str().contains("{\n  \"@id\""),
         "response should be json-ad"
@@ -122,20 +107,21 @@ async fn server_tests() {
 
     // Get JSON-LD
     let req = build_request_authenticated("/properties", &appstate)
-        .header("Accept", "application/ld+json");
-    let mut resp = test::call_service(&mut app, req.to_request()).await;
+        .insert_header(("Accept", "application/ld+json"));
+    let resp = test::call_service(&app, req.to_request()).await;
     assert!(resp.status().is_success(), "setup not returning JSON-LD");
-    let body = resp.take_body();
+    let body = get_body(resp);
     assert!(
         body.as_str().contains("@context"),
         "response should be json-ld"
     );
 
     // Get turtle
-    let req = build_request_authenticated("/properties", &appstate).header("Accept", "text/turtle");
-    let mut resp = test::call_service(&mut app, req.to_request()).await;
+    let req = build_request_authenticated("/properties", &appstate)
+        .insert_header(("Accept", "text/turtle"));
+    let resp = test::call_service(&app, req.to_request()).await;
     assert!(resp.status().is_success());
-    let body = resp.take_body();
+    let body = get_body(resp);
     assert!(
         body.as_str().starts_with("<htt"),
         "response should be turtle"
@@ -144,12 +130,19 @@ async fn server_tests() {
     // Get Search
     // Does not test the contents of the results - the index isn't built at this point
     let req = build_request_authenticated("/search?q=setup", &appstate);
-    let mut resp = test::call_service(&mut app, req.to_request()).await;
+    let resp = test::call_service(&app, req.to_request()).await;
     assert!(resp.status().is_success());
-    let body = resp.take_body();
+    let body = get_body(resp);
     println!("{}", body.as_str());
     assert!(
         body.as_str().contains("/results"),
         "response should be a search resource"
     );
 }
+
+/// Gets the body from the response as a String. Why doen't actix provide this?
+fn get_body(resp: ServiceResponse) -> String {
+    let boxbody = resp.into_body();
+    let bytes = boxbody.try_into_bytes().unwrap();
+    String::from_utf8(bytes.as_ref().into()).unwrap()
+}
